@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2013-2015 Hannu Väisänen (Hannu.Vaisanen@uef.fi)
+# Copyright 2013-2016 Hannu Väisänen (Hannu.Vaisanen@uef.fi)
 # Program to generate old spellings and common spelling mistakes for Voikko lexicon.
 
 # This program is free software; you can redistribute it and/or modify
@@ -35,10 +35,12 @@
 # spellings and spelling errors that do not exist in real life.
 
 # Compiling (in directory voikko-fi):
-# make vvfst-sukija; make vvfst-sukija-install DESTDIR=~/vvfst/voikkodict/
+# make vvfst-sukija DESTDIR=~/vvfst/voikkodict/ VOIKKO_VARIANT=sukija VOIKKO_DESCRIPTION="suomi (Sukija)"
+# make vvfst-sukija-install DESTDIR=~/vvfst/voikkodict/ VOIKKO_VARIANT=sukija VOIKKO_DESCRIPTION="suomi (Sukija)"
 
 # Compiling (in directory voikko-fi/vvfst):
-# cd ..; make vvfst-sukija; make vvfst-sukija-install DESTDIR=~/vvfst/voikkodict/; cd vvfst
+# cd ..; make vvfst-sukija DESTDIR=~/vvfst/voikkodict VOIKKO_VARIANT=sukija VOIKKO_DESCRIPTION="suomi (Sukija)"; cd vvfst
+# cd ..; make vvfst-sukija-install DESTDIR=~/vvfst/voikkodict VOIKKO_VARIANT=sukija VOIKKO_DESCRIPTION="suomi (Sukija)"; cd vvfst
 
 # Testing (in directory voikko-fi/vvfst):
 # foma -e "read att all-sukija.att" -e "save stack sukija.fst" -e "quit"
@@ -67,14 +69,16 @@ infile = codecs.open (OPTIONS["destdir"] + u"/all.lexc", "r", "UTF-8")
 outfile = codecs.open (OPTIONS["destdir"] + u"/all-sukija.lexc", 'w', 'UTF-8')
 sukijafile = codecs.open (OPTIONS["destdir"] + u"/poikkeavat-sukija.lexc", 'r', 'UTF-8')
 
-C = u"[qwrtpsšdfghjklzžxcvbnm]"  # Consonants.
-V = u"[aeiouüyåäö]"              # Vovels.
+C = u"[qwrtpsšdfghjklzžxcvbnm]"      # Kerakkeet.
+K = u"[qwrtpsšdfghjklzžxcvbnmaiou]"  # Kerakkeet + ääntiöitä.
+V = u"[aeiouüyåäö]"                  # Ääntiöt.
 A = u"[aä]"
 U = u"[uy]"
 
 def makeRePattern (wordClass, word):
-    u = u"^\\[%s\\]\\[Xp\\].*%s\\[X\\]" % (wordClass, word)
+    u = u"^\\[%s\\](\\[I..\\])?\\[Xp\\].*%s\\[X\\]" % (wordClass, word)
     u = u.replace ('C', C)
+    u = u.replace ('K', K)
     u = u.replace ('V', V)
     u = u.replace ('A', A)
     u = u.replace ('U', U)
@@ -93,119 +97,51 @@ def replace (s, old, new):
     return u
 
 
+def replaceX (s, old, new):
+    if new.endswith("n"):
+        return s.replace (old + "[X]", new + "i[X]")
+    else:
+        return s.replace (old + "[X]", new + "[X]")
+
+
 def replace_and_write (line, string1, string2):
     s = replace (line, string1, string2)
     outfile.write (s)
 
+re_oittaa1 = makeRe (u"Lt", u".Koittaa")
+re_oittaa2 = makeRe (u"Lt", u".Köittää")
 
-re_adi = makeRe (u"Ln", u".Cadi")
-re_odi = makeRe (u"Ln", u".Codi")
-re_ofi = makeRe (u"Ln", u".Cofi")
-re_ogi = makeRe (u"Ln", u".Cogi")
-re_oli = makeRe (u"Ln", u".Coli")
-re_omi = makeRe (u"Ln", u".Comi")
-re_oni = makeRe (u"Ln", u".Coni")
-re_ori = makeRe (u"Ln", u".Cori")
+re_ottaa1 = makeRe (u"Lt", u".Kottaa")
+re_ottaa2 = makeRe (u"Lt", u".Köttää")
 
-re_OOri = makeRe (u"Ln", u".Cööri")
-re_UUri = makeRe (u"Ln", u"..UUri")
+re_oitella1 = makeRe (u"Lt", u".Koitella")
+re_oitella2 = makeRe (u"Lt", u".Köitellä")
 
-re_adinen = makeRe (u"Ln", u".Cadinen")
-re_odinen = makeRe (u"Ln", u".Codinen")
-re_ofinen = makeRe (u"Ln", u".Cofinen")
-re_oginen = makeRe (u"Ln", u".Coginen")
-re_olinen = makeRe (u"Ln", u".Colinen")
-re_ominen = makeRe (u"Ln", u".Cominen")
-re_oninen = makeRe (u"Ln", u".Coninen")
-re_orinen = makeRe (u"Ll", u".Corinen")
-
-re_grafia   = makeRe (u"Ln", u"grafia")
-re_grafinen = makeRe (u"Ll", u"grafinen")
-re_logia    = makeRe (u"Ln", u"logia")
-re_loginen  = makeRe (u"Ll", u"loginen")
-
-re_torio = makeRe (u"Ln", u"torio")
-
-re_oittaa1 = makeRe (u"Lt", u".Coittaa")
-re_oittaa2 = makeRe (u"Lt", u".Cöittää")
-
-re_ottaa1 = makeRe (u"Lt", u".Cottaa")
-re_ottaa2 = makeRe (u"Lt", u".Cöttää")
-
-re_oitella1 = makeRe (u"Lt", u".Coitella")
-re_oitella2 = makeRe (u"Lt", u".Cöitellä")
-
-re_otella1 = makeRe (u"Lt", u".Cotella")
-re_otella2 = makeRe (u"Lt", u".Cötellä")
+re_otella1 = makeRe (u"Lt", u".Kotella")
+re_otella2 = makeRe (u"Lt", u".Kötellä")
 
 re_isoida = makeRe (u"Lt", u"isoida") # Organisoida => organiseerata.
 
-re_oitin = makeRe (u"Ln", u".Coitin")
-re_aatio = makeRe (u"Ln", u".Caatio")
-re_uutio = makeRe (u"Ln", u".Cuutio")
-re_uusio = makeRe (u"Ln", u".Cuusio")
-re_tio   = makeRe (u"Ln", u"([^a]i|k)tio") # Traditio, funktio, mutta ei aitio.
-
-re_toninen = makeRe (u"Ll", u".toninen")
-re_iivinen = makeRe (u"Ll", u"Ciivinen")
-re_aalinen = makeRe (u"Ll", u"aalinen")
-re_geeninen = makeRe (u"Ll", u"geeninen")
-re_oittainen = makeRe (u"Ll", u"oittainen")
-
 re_nuolaista = re.compile (u"\\[Lt\\].* Nuolaista_", re.UNICODE)
 re_rangaista = re.compile (u"\\[Lt\\].* Rangaista_", re.UNICODE)
 
 re_Xiljoona = re.compile (u"\\A(?:\\[Bc\\]|\\[Sn\\]|@).*(b|m|tr)iljoon", re.UNICODE)
 
-re_eikAs = makeRe (u"Ll", u"eikAs")
-re_8_9 = re.compile (u"\\[Xp\\](ka|y)hdeks")
 re_tautua1 = makeRe (u"Lt", u"tautua")
 re_tautua2 = makeRe (u"Lt", u"täytyä")
 
-
-# Words to be excluded.
-#
-re_adi_x = re.compile (u"\\A\[Ln\]\[Xp\](faradi|pikofaradi|stadi)\[X\]")
-re_ogi_x = re.compile (u"\\A\[Ln\]\[Xp\](blogi|grogi|judogi)\[X\]")
-re_omi_x = re.compile (u"\\A\[Ln\]\[Xp\](binomi|bromi|dibromi|genomi|kromi|trinomi)\[X\]")
-re_oni_x = re.compile (u"\\A\[Ln\]\[Xp\](ikoni)\[X\]")
-re_ori_x = re.compile (u"\\A\[Ln\]\[Xp\](hevosori|jalostusori|reettori|siitosori)\[X\]")
-
-re_logia_x = re.compile (u"\\A\[Ln\]\[Xp\](genealogia|trilogia)\[X\]")
-
 re_isoida_x = re.compile (u"\\A\[Lt\]\[Xp\](dramatisoida|karakterisoida)\[X\]")
 
 re_A = re.compile (u"[aou]")
 
+re_oitin = makeRe (u"Ln", u".Coitin")
+
+re_aatio = makeRe (u"Ln", u".Caatio")
+re_uutio = makeRe (u"Ln", u".Cuutio")
+re_uusio = makeRe (u"Ln", u".Cuusio")
+re_tio   = makeRe (u"Ln", u"([^a]i|k)tio") # Traditio, funktio, mutta ei aitio.
 
 spelling_pattern_list = [
-  (re_adi, u"ad", u"aad", re_adi_x),  # Serenadi  => senenaadi.
-  (re_odi, u"od", u"ood"),            # Aplodi    => aploodi.
-  (re_ofi, u"of", u"oof"),            # Filosofi  => filosoofi.
-  (re_ogi, u"og", u"oog", re_ogi_x),  # Arkeologi => arkeoloogi.
-  (re_oli, u"ol", u"ool"),            # Symboli   => symbooli.
-  (re_omi, u"om", u"oom", re_omi_x),  # Atomi     => atoomi.
-  (re_oni, u"on", u"oon", re_oni_x),  # Telefoni  => telefooni.
-  (re_ori, u"or", u"oor", re_ori_x),  # Pehtori   => pehtoori.
-
-  (re_OOri,     u"öör",   u"ör"),     # Amatööri => amatöri.
-  (re_UUri,     u"uur",   u"ur"),
-
-  (re_adinen,   u"adi",    u"aadi"),
-  (re_odinen,   u"odi",    u"oodi"),
-  (re_ofinen,   u"ofi",    u"oofi"),
-  (re_oginen,   u"ogi",    u"oogi"),
-  (re_olinen,   u"oli",    u"ooli"),
-  (re_ominen,   u"omi",    u"oomi"),
-  (re_oninen,   u"oni",    u"ooni"),
-  (re_orinen,   u"ori",    u"oori"),
-
-  (re_grafia,   u"grafi",  u"graafi"),
-  (re_grafinen, u"grafi",  u"graafi"),
-  (re_logia,    u"logi",   u"loogi", re_logia_x),
-  (re_loginen,  u"logi",   u"loogi"),
-
-  (re_torio, u"torio", u"toorio"),
 
   (re_oitin, u"oit", u"ot"),  # Kirjoitin => kirjotin (esim. kirjo(i)ttimen).
 
@@ -228,16 +164,8 @@ spelling_pattern_list = [
 
   (re_isoida, u"isoida", u"iseerata", u"iso", u"iseer", u"Kanavoida", u"Saneerata", u"Voida", u"Saneerata", re_isoida_x),
 
-  (re_toninen, u"toni", u"tooni"),
-  (re_iivinen, u"iivi", u"ivi"),
-  (re_aalinen, u"aali", u"ali"),
-  (re_geeninen, u"geeni", u"geni"),
-  (re_oittainen, u"oittai", u"ottai"),
-
   (re_nuolaista, u"Nuolaista_"),
   (re_rangaista, u"Rangaista_"),
-
-  (re_eikAs, u"eik", u"ehik"),
 ]
 
 
@@ -309,8 +237,12 @@ def generate_from_pattern_1 (line, pattern_list):
 def generate_from_pattern_2 (line, pattern, string, p1, p2, s1, s2):
     if pattern.match (line):
         for x in p1:
+#            s = replaceX (line, string, x)
+#            replace_and_write (s, string, x)
             replace_and_write (line, string, x)
         for x in p2:
+#            s = replaceX (line, string, x)
+#            replace_and_write (s.replace(s1,s2), string, x)
             replace_and_write (line.replace(s1,s2), string, x)
 
 
@@ -319,7 +251,7 @@ def generate_from_pattern_2 (line, pattern, string, p1, p2, s1, s2):
 #
 #    (u"", (u"", u"")),
 #
-word_list = [
+zzz_word_list = [
     (u"aarteisto",        (u"aarteisto",   u"aartehisto")),
     (u"Abessinia",        (u"abessini",    u"abessiini", u"abyssini", "abyssiini")),
     (u"Afganistan",       (u"afganistan",  u"afghanistan")),
@@ -352,6 +284,7 @@ word_list = [
     (u"assistentti",      (u"assistent",     u"asistent")),
     (u"at=tribuutti",     (u"at[Bm]tribuut:attribuut", u"at[Bm]ribuut:atribuut")),
     (u"Australia",        (u"Australi",      u"Austraali")),
+    (u"bakteriofagi",     (u"bakteriofag",   u"bakteriofaag")),
     (u"barbaari",         (u"barbaar",       u"barbar")),
     (u"beduiini",         (u"beduiin",       u"beduin")),
     (u"biljardi",         (u"biljard",       u"biljaard")),
@@ -375,6 +308,7 @@ word_list = [
     (u"erillinen",        (u"erilli",        u"erili")),
     (u"eris=kummallinen", (u"kummalli",      u"kummali", u"kumalli")),
     (u"erinäinen",        (u"erinäi",        u"erinnäi")),
+    (u"eskadroona",       (u"eskadroon",     u"eskadron")),
     (u"eteinen",          (u"etei",          u"etehi")),
     (u"evankelinen",      (u"evankeli",      u"evankeeli")),
     (u"fakiiri",          (u"fakiir",        u"fakir")),
@@ -401,22 +335,27 @@ word_list = [
     (u"inhimillinen",     (u"inhimilli",     u"inhimmilli")),
     (u"inkvisiittori",    (u"inkvisiittor",  u"inkvisitor", u"inkvisiitor")),
     (u"inkvisitio",       (u"inkvisitio",    u"inkvisiitio")),
-    (u"insinööri",        (u"insinöör",      u"insinör")),
+    (u"insinööri",        (u"insinöör",      u"insinör", u"insenjöör")),
     (u"invalidi",         (u"invalid",       u"invaliid")),
     (u"Italia",           (u"Ital",          u"Itaal")),
+    (u"jakaranda",        (u"jakarand",      u"jacarand")),
     (u"janitsaari",       (u"janitsaar",     u"janitsar", u"janitschar", u"janitschaar", u"janitshaar")),
+    (u"Japani",           (u"japan",         u"jaappan", u"jaapan")),
     (u"juliaaninen",      (u"juliaani",      u"juliani")),
     (u"juridinen",        (u"juridi",        u"juriidi")),
     (u"kaanon",           (u"kaanon",        u"kanon")),
+    (u"kabbalisti",       (u"kabbalist",     u"kabalist")),
     (u"kaleeri",        (u"kaleer",      u"kaler")),
     (u"kamari",         (u"kamar",       u"kammar")),
     (u"kameli",         (u"kamel",       u"kameel")),
     (u"kamiina",        (u"kamiin",      u"kamin")),
     (u"kampanja",       (u"kampanj",     u"kamppanj")),
     (u"kaneli",         (u"kanel",       u"kaneel")),
+    (u"kannibaali",     (u"kannibaal",   u"kannibal")),
     (u"kanuuna",        (u"kanuun",      u"kanun", u"kanoon", u"kanon")),
     (u"kaoottinen",     (u"kaootti",     u"kaaootti", u"kaaotti", u"kaotti")),
     (u"kapteeni",       (u"kapteen",     u"kaptein")),
+    (u"karahvi",        (u"karahv",      u"karaff")),
     (u"kategoria",      (u"kategor",     u"kategoor")),
     (u"kauan",          ((u"kauaa",      u"kauvaa"),
                          (u"kauan",      u"kauvan"),
@@ -434,6 +373,7 @@ word_list = [
     (u"kerubi",         (u"kerub",       u"keruub", u"kheruub")),
     (u"keskimmäinen",   (u"keskimmäi",   u"keskimäi")),
     (u"kiiras=torstai", (u"torsta",      u"tuorsta")),
+    (u"kimnaasi",       (u"kimnaas",     u"kymnaas", u"kymnas")),
     (u"kirjoitelma",    (u"kirjoitelm",  u"kirjotelm")),
     (u"klinikka",       (u"klinik",      u"kliniik")),
     (u"kollega",        (u"kolleg",      u"kolleeg")),
@@ -460,6 +400,7 @@ word_list = [
     (u"Kööpen=hamina",  (u"kööpen[Bm]hamin:kööpenhamin", u"köpen[Bm]hamin:köpenhamin")),
     (u"laitimmainen",   (u"laitimmai",   u"laitimai")),
     (u"langobardi",     (u"langobard",   u"longobard")),
+    (u"lankata",        (u"lank",        u"plank")),
     (u"lauantai",       (u"lauanta",     u"lauvanta")),
     (u"lauantaisin",    (u"lauantaisin", u"lauvantaisin")),
     (u"leegio",         (u"leegio",      u"legio")),
@@ -480,7 +421,8 @@ word_list = [
     (u"mamselli",       (u"mamsell",     u"mamsel")),
     (u"mansetti",       (u"manset",      u"manshet")),
     (u"marsilainen",    (u"marsilai",    u"marssilai")),
-    (u"marttyyri",      (u"marttyyr",    u"martyr")),
+    (u"matemaattinen",  (u"matemaatti",  u"matemaatilli")),
+    (u"marttyyri",      (u"marttyyr",    u"martyr", u"marttyr")),
     (u"matrikkeli",     (u"matrikkel",   u"matrikel")),
     (u"mekaaninen",     (u"mekaani",     u"mekani")),
     (u"melankolinen",   (u"melankoli",   u"melankooli")),
@@ -501,6 +443,7 @@ word_list = [
     (u"non=ag=gressio",  (u"non[Bm]ag[Bm]gressio:nonaggressio", u"non[Bm]ag[Bm]ressio:nonagressio")),
     (u"Nubia",           (u"nubi",        u"nuubi")),
     (u"odottaa",         (u"odot",        u"oot")),
+    (u"oopiumi",         (u"oopium",      u"ooppium")),
     (u"oraakkeli",       (u"oraakkel",    u"oraakel", u"orakel")),
     (u"ottomaani",       (u"ottomaan",    u"ottoman")),
     (u"paitsi",          (u"paitsi",      u"paitse")),
@@ -522,8 +465,10 @@ word_list = [
     (u"perimmäinen",     (u"perimmäi",    u"perimäi")),
     (u"persoona",        (u"persoon",     u"person")),
     (u"piispa",          (u"piisp",       u"pisp")),
-    (u"pioneeri",        (u"pioneer",     u"pioner")),
+    (u"piletti",         (u"pilet",       u"piljet")),
+    (u"pioneeri",        (u"pioneer",     u"pioner", u"pionieer", u"pionier")),
     (u"pioni",           (u"pion",        u"pioon")),
+    (u"pistooli",        (u"pistool",     u"pistol")),
     (u"pitaali",         (u"pitaal",      u"pital")),
     (u"plataani",        (u"plataan",     u"platan")),
     (u"plebeiji",        (u"plebeij",     u"plebej")),
@@ -544,31 +489,37 @@ word_list = [
     (u"pudottaa",        (u"pudo",        u"puo")),
     (u"puolimmainen",    (u"puolimmai",   u"puolimai")),
     (u"pyramidi",        (u"pyramid",     u"pyramiid")),
+    (u"Pälk=järvi",      (u"pälk[Bm]järv:pälkjärv", u"pelg[Bm]järv:pelgjärv")),
+    (u"Pälk=saari",      (u"pälk[Bm]saar:pälksaar", u"pelg[Bm]saar:pelgsaar")),
     (u"päällikkö",       (u"päällik",     u"päälik")),
     (u"päällimmäinen",   (u"päällimmäi",  u"päällimäi", u"päälimäi", u"päälimmäi")),
     (u"päärynä",         ((u"pääryn", u"pääron", u"NimisanaPeruna_ä", u"NimisanaPeruna_aä"), )),
+    (u"pääskynen",       (u"pääsky",      u"pääskyi")),
     (u"rakuuna",         (u"rakuun",      u"rakun")),
-    (u"rangaistus",      (u"rangaistu",   u"rankaistu")),
+    (u"rangaistus",      (u"rangaistu",   u"rankaistu", u"rangastu")),
     (u"reettori",        (u"reettor",     u"reetor")),
+    (u"reistraattori",   (u"reistraattor", u"reistrator", u"registraattor", u"registrator")),
     (u"reunimmainen",    (u"reunimmai",   u"reunimai")),
     (u"romanttinen",     (u"romantti",    u"romanti", u"romantilli")),
     (u"safiiri",         (u"safiir",      u"safir")),
     (u"saippua",         (u"saippu",      u"saipu")),
+    (u"sairaalloinen",   (u"sairaalloi",  u"sairaaloi", u"sairalloi", u"sairaloi", u"sairaanloi")),
     (u"salamanteri",     (u"salamanter",  u"salamander")),
     (u"saman=lainen",    (u"saman[Bm]lai:samanlai", u"samal[Bm]lai:samallai")),
     (u"samojedi",        (u"samojed",     u"samojeed")),
     (u"sampanja",        (u"sampanj",     u"samppanj")),
     (u"sankaruus",       (u"sankaruu",    u"sankariu")),
-    (u"saraseeni",       (u"saraseen",    u"sarasen")),
     (u"sapatti",         (u"sapat",       u"sabat")),
     (u"sapeli",          (u"sapel",       u"sapeel")),
+    (u"saraseeni",       (u"saraseen",    u"sarasen")),
+    (u"sarkofagi",       (u"sarkofag",    u"sarkofaag")),
     (u"satraappi",       ((u"satraap",    u"satrap"),
                           (u"satraap",    u"satraap", u"NimisanaSinappi_a", u"NimisanaPaperi_a"),
                           (u"satraap",    u"satrap",  u"NimisanaSinappi_a", u"NimisanaPaperi_a"))),
     (u"seminaari",       (u"seminaar",    u"seminar")),
     (u"senaatti",        ((u"senaat",     u"senaat", u"NimisanaSalaatti_a", u"NimisanaPaperi_a"),
                           (u"senaat",     u"senat",  u"NimisanaSalaatti_a", u"NimisanaPaperi_a"))),
-    (u"senaattori",      (u"senaattor",   u"senaator")),
+    (u"senaattori",      (u"senaattor",   u"senaator", u"senator")),
     (u"sensuuri",        (u"sensuur",     u"senssuur", u"senssur")),
     (u"serafi",          (u"seraf",       u"seraaf")),
     (u"serenad",         (u"serenad",     u"serenaat")),
@@ -582,6 +533,7 @@ word_list = [
     (u"sitä=paitsi",     (u"paitsi",      u"paitse")),
     (u"siviili",         (u"siviil",      u"sivil")),
     (u"sivilisaatio",    (u"sivilisaatio", u"siviilisaatio")),
+    (u"skorpioni",       (u"skorpion",     u"skorpioon",  u"skorppioon")),
     (u"slaavilainen",    (u"slaavilai",    u"slavilai")),
     (u"soolo",           (u"soolo",        u"solo")),
     (u"soopeli",         (u"soopel",       u"sopel", u"soobel")),
@@ -590,7 +542,8 @@ word_list = [
                           (u"stationaari", u"stationari"))),
     (u"stoola",          (u"stool",        u"stol")),
     (u"sulhanen",        (u"sulha",        u"sulhai")),
-    (u"sydämistyä",      (u"sydämisty",   u"sydämmisty", u"sydämmysty", u"sydämysty")),
+    (u"suppressio",      (u"suppressio",   u"supressio")),
+    (u"sydämistyä",      (u"sydämisty",    u"sydämmisty", u"sydämmysty", u"sydämysty")),
     (u"synagoga",        (u"synagog",      u"synagoog")),
     (u"taimmainen",      (u"taimmai",      u"takimai", u"taemmai", u"taaemmai")),
     (u"talismaani",      (u"talismaan",    u"talisman")),
@@ -611,13 +564,17 @@ word_list = [
     (u"tällainen",       ((u"tällai",      u"tällai", u"NimiLaatusanaNainenInen_a", u"NimiLaatusanaNainenInen_ä"),
                           (u"tällai",      u"tälläi", u"NimiLaatusanaNainenInen_a", u"NimiLaatusanaNainenInen_aä"))),
     (u"ulommainen",      (u"ulommai",      u"uloimmai")),
+    (u"unioni",          (u"union",        u"unioon")),
     (u"upseeri",         (u"upseer",       u"upser", u"upsier")),
     (u"upseeristo",      (u"upseeristo",   u"upsieristo")),
     (u"vaillinainen",    (u"vaillinai",    u"vaillinnai")),
     (u"vaivalloinen",    (u"vaivalloi",    u"vaivaloi")),
     (u"vaientaa",        (u"vaien",        u"vaijen")),
+    (u"valaistus",       (u"valaistu",     u"valastu")),
     (u"vampyyri",        (u"vampyyr",      u"vampyr")),
+    (u"varjagi",         (u"varjag",       u"varjaag")),
     (u"vasemmisto",      (u"vasemmisto",   u"vasemisto")),
+    (u"vavistus",        (u"vavistu",      u"vapistu")),
     (u"viheriöidä",      (u"viheriö",      u"viherjö")),
     (u"vihkiäinen",      (u"vihkiäi",      u"vihkijäi")),
     (u"vihollinen",      (u"viholli",      u"vihoilli")),
@@ -626,7 +583,17 @@ word_list = [
     (u"Väisänen",        (u"väisä",        u"wäisä")),
     (u"ylhäällä",        (u"ylhää",        u"ylähä")),
     (u"ylimmäinen",      (u"ylimmäi",      u"ylimäi")),
-    (u"öinen",           (u"öi",           u"öilli")),
+    (u"Zarathustra",       (u"zarathustr",     u"zarahustr")),
+    (u"zarathustralainen", (u"zarathustralai", u"zarahustralai")),
+    (u"öinen",             (u"öi",             u"öilli")),
+
+]
+
+word_list = [
+    (u"stationaarinen",  ((u"stationaari", u"stationääri", u"LaatusanaNainenInen_a ", u"LaatusanaNainenInen_ä"),)),
+
+    (u"tällainen",       ((u"tällai",      u"tällai", u"NimiLaatusanaNainenInen_a", u"NimiLaatusanaNainenInen_ä"),
+                          (u"tällai",      u"tälläi", u"NimiLaatusanaNainenInen_a", u"NimiLaatusanaNainenInen_aä"))),
 
     (u"lainen",  lambda line, word: replace_and_write (line.replace(u"lai",u"läi"), u"NimiLaatusanaNainen_a", u"NimiLaatusanaNainen_ä")),
 
@@ -663,8 +630,9 @@ word_list = [
     (u"päre",  [u"[Ln][Xp]päre[X]päre[Ses][Ny]nnä:pärennä NimisanaLiOlV_ä ;"]),
     (u"terve", [u"[Lnl][Xp]terve[X]terve[Ses][Ny]nnä:tervennä NimisanaLiOlV_ä ;"]),
 
-    (u"kaivu", [u"[Ln][Xp]kaivu[X]kaivu:kaivu NimisanaPuu_a ;",
-                u"[Ln][Xp]kaivu[X]kaivu[Sill][Ny]usee:kaivuusee NimisanaLiOlN_a ;"]),
+    (u"kaivu", [u"[Ln][Xp]kaivu[X]kaivu[Sill][Ny]usee:kaivuusee NimisanaLiOlN_a ;"]),
+#    (u"kaivu", [u"[Ln][Xp]kaivu[X]kaivu:kaivu NimisanaPuu_a ;",
+#                u"[Ln][Xp]kaivu[X]kaivu[Sill][Ny]usee:kaivuusee NimisanaLiOlN_a ;"]),
 ]
 
 
@@ -909,7 +877,9 @@ while True:
     line = re.sub (ei_vertm, u"", line)
     if line.find (u"=") >= 0:
         line = line.replace (u"@P.YS_EI_JATKOA.ON@", u"")
-        
+    if line.find ("lähtöinen") >= 0:
+        line = line.replace ("@R.YS_ALKANUT@", "")
+
     if OPTIONS["sukija-ys"]:
         line = line.replace (u"@P.YS_EI_JATKOA.ON@", u"")
         line = line.replace (u"@D.YS_EI_JATKOA@", u"")
@@ -924,8 +894,6 @@ while True:
     generate_from_pattern_2 (line, re_aatio, u"aatio", (u"atio", u"atsio"), (u"atsion", u"atsioon"), u"NimisanaAutio_a", u"NimisanaPaperi_a")
     generate_from_pattern_2 (line, re_uutio, u"uutio", (u"utio", u"utsio"), (u"utsion", u"utsioon"), u"NimisanaAutio_a", u"NimisanaPaperi_a")
 
-    if re_8_9.search (line):
-        write_8_9 (line)
 
     r = base_form_re.search (line)
     if r:
